@@ -1,3 +1,4 @@
+from dataclasses import dataclass
 from pydantic import BaseModel
 from typing import Optional
 from datetime import datetime
@@ -29,18 +30,26 @@ class FileKey(BaseModel):
     version: FileKeyVersion
     tag: Optional[str]
 
+    class Config:
+        use_enum_values = True
+
 class PlainFileKey(BaseModel):
     version: PlainFileKeyVersion
     key: str
     iv: str
     tag: Optional[str]
 
+    class Config:
+        use_enum_values = True
+
 class PublicKeyContainer(BaseModel):
     version: UserKeyPairVersion
     publicKey: str
     createdAt: Optional[datetime]
     expireAt: Optional[datetime]
     createdBy: Optional[int]
+    class Config:
+        use_enum_values = True
 
 class PrivateKeyContainer(BaseModel):
     version: UserKeyPairVersion
@@ -49,6 +58,9 @@ class PrivateKeyContainer(BaseModel):
     expireAt: Optional[datetime]
     createdBy: Optional[int]
 
+    class Config:
+        use_enum_values = True
+
 class UserKeyPairContainer(BaseModel):
     privateKeyContainer: PrivateKeyContainer
     publicKeyContainer: PublicKeyContainer
@@ -57,3 +69,19 @@ class PlainUserKeyPairContainer(BaseModel):
     privateKeyContainer: PrivateKeyContainer
     publicKeyContainer: PublicKeyContainer
 
+class KeyState(Enum):
+    none = "none"
+    available = "available"
+    pending = "pending"
+
+
+@dataclass
+class EncryptionInfo:
+    userKeyState: KeyState
+    roomKeyState: KeyState
+    dataSpaceKeyState: KeyState
+    
+    class Config:
+        use_enum_values = True
+
+
